@@ -57,10 +57,11 @@ class CLI(click.Group):
         return click.Group.get_command(self, ctx, command)
 
 
-def print_version(ctx, param, value):  # # pylint: disable=W0613
-    if value or not ctx.resilient_parsing:
-        print(__version__)
-        ctx.exit()
+def print_version(ctx, param, value):  # pylint: disable=W0613
+    if not value or ctx.resilient_parsing:
+        return
+    print(__version__)
+    ctx.exit()
 
 
 @click.group(cls=CLI, context_settings=CONTEXT_SETTINGS)
